@@ -72,9 +72,8 @@ impl Arc<u8> {
         if length == 0 {
             Self { pointer: null() }
         } else {
-            let pointer = unsafe {
-                &mut *(alloc(Layout::from_size_align(length, 1).unwrap()) as *mut ArcInner<u8>)
-            };
+            let pointer =
+                unsafe { &mut *(alloc(Self::buffer_layout(length)) as *mut ArcInner<u8>) };
 
             pointer.count = AtomicUsize::new(INITIAL_COUNT);
 
@@ -87,6 +86,14 @@ impl Arc<u8> {
     pub fn empty() -> Self {
         Self::buffer(0)
     }
+
+    fn buffer_layout(length: usize) -> Layout {
+        Layout::new::<ArcInner<()>>()
+            .extend(Layout::array::<u8>(length).unwrap())
+            .unwrap()
+            .0
+            .pad_to_align()
+    }
 }
 
 impl<T> From<T> for Arc<T> {
@@ -157,7 +164,7 @@ impl<T> Drop for Arc<T> {
             unsafe {
                 drop_in_place(self.as_ptr_mut());
 
-                // TODO This is invalid for Arc<u8> buffer.
+                // TODO The layout is invalid for Arc<u8> buffer.
                 dealloc(
                     self.inner() as *const ArcInner<T> as *mut u8,
                     Self::inner_layout(),
